@@ -1,5 +1,4 @@
 from argparse import RawTextHelpFormatter
-from collections import OrderedDict
 
 from fa import utils, context
 
@@ -11,10 +10,10 @@ EXAMPLE:
     0x00000004: 05 06 07 08
 
     results = []
-    -> find-bytes-ida --or '01 02 03 04'
+    -> find-bytes-ida '01 02 03 04'
     result = [0]
 
-    -> find-bytes-ida --or '05 06 ?? 08'
+    -> find-bytes-ida '05 06 ?? 08'
     results = [0, 4]
 '''
 
@@ -23,13 +22,11 @@ def get_parser():
     p = utils.ArgumentParserNoExit('find-bytes-ida',
                                    description=DESCRIPTION,
                                    formatter_class=RawTextHelpFormatter)
-    p.add_argument('--or', action='store_true')
     p.add_argument('expression')
     return p
 
 
 @context.ida_context
-@utils.yield_unique
 def find_bytes_ida(expression, segments=None):
     for address in utils.ida_find_all(expression):
         yield address
@@ -37,11 +34,4 @@ def find_bytes_ida(expression, segments=None):
 
 def run(segments, args, addresses, interpreter=None, **kwargs):
     results = find_bytes_ida(args.expression)
-
-    retval = set(addresses)
-    if getattr(args, 'or'):
-        retval.update(results)
-    else:
-        raise ValueError("must specify --or option")
-
-    return list(OrderedDict.fromkeys(retval))
+    return addresses + results
